import { AnimationInput, AnimationsByName, NormalizedAnimation } from './AnimationInput';
import { ToggleTransitions } from './hooks/useTransitioningToggle';
/**
 * Returns an edited animation that runs it's last keyframe infinitely (until interrupted)
 * Useful for controlled animations that are tied to state rather than transitions
 *
 * The edits are:
 * - set iterations: 'Infinity' on the last Keyframe in the Keyframes list
 * - set fill: 'forwards' on the Animation options
 */
export declare const toPersistedAnimation: (toPersist: AnimationInput) => NormalizedAnimation;
/**
 * Returns an edited animation that retains the style of its last keyframe
 * Useful for controlled animations that are tied to transitions so that when the transition is complete, the style persists in the new state
 *
 * The edits are:
 * - set fill: 'forwards' on the Animation options
 */
export declare const toTransitionAnimation: (animation: AnimationInput) => NormalizedAnimation;
/**
 * Helper to create a complete toggling animation by reversing a given togglingOn animation
 *
 * The edits are:
 * - set fill: 'forwards' on the Animation options
 */
export declare const toToggleAnimations: (togglingOn: AnimationInput) => AnimationsByName<ToggleTransitions>;
/**
 * Helper to create AnimationsByName for a SimpleTransition animation
 *
 * See {@link hooks.useSimpleTransitioningState}
 *
 * @param transition
 */
export declare const toSimpleTransitionAnimations: (transition: AnimationInput) => AnimationsByName<'transition'>;
