import React, { RefAttributes } from 'react';
import { AnimatedProps, HTMLIntrinsics, TagHTMLElement } from "./common";
export type ControlledAnimatedProps<A extends string, T extends HTMLIntrinsics = "div"> = {
    /**
     * The currentAnimation that controls this component.
     * On changing this prop to a non-null value, will start the animation at animations[currentAnimation]
     * If given null, will cancel() any current animations
     * If given a new or null value while the previous aninmation is not finished(), will commit the current style to the element and call onAnimationEnd
     */
    currentAnimation: A | null;
} & AnimatedProps<A, T>;
/**
 * An Animated component that is controlled by the currentAnimation prop
 * The component may use a different HTML tag delegate via the `as` prop
 * May accept a ref to forward to the HTML tag delegate.
 * Note: forwarding a ref returned from {@link hooks.useAnimatedRef} may result in undeterministic behavior
 *
 * @typeParam A the accepted animation names
 * @typeParam T the HTML Tag delegate
 */
declare const ControlledAnimated: <A extends string = string, T extends keyof JSX.IntrinsicElements = "div">(props: {
    /**
     * The currentAnimation that controls this component.
     * On changing this prop to a non-null value, will start the animation at animations[currentAnimation]
     * If given null, will cancel() any current animations
     * If given a new or null value while the previous aninmation is not finished(), will commit the current style to the element and call onAnimationEnd
     */
    currentAnimation: A;
} & import("./common").NonHTMLAnimatedProps<A, T> & Omit<import("./common").TagHTMLAttributes<T>, "onAnimationEnd"> & React.RefAttributes<TagHTMLElement<T>>) => React.ReactElement<any, any>;
export default ControlledAnimated;
