import React from "react";
import { HTMLIntrinsics, TagHTMLElement, AnimatedProps } from "./common";
export type HoverAnimations = 'hovering' | 'notHovering';
type HoverAnimatedProps<A extends string, T extends HTMLIntrinsics> = {
    /**
     * The optional currentAnimation override that may control this component
     * If present, will override the animation for the current hover state
     * If null or undefined, the component will animate based on the hover state
     * Analogous to currentAnimation in {@link components/ControlledAnimated.ControlledAnimatedProps}
     */
    currentAnimation?: A | null;
} & AnimatedProps<HoverAnimations | A, T>;
/**
 * An Animated component that will track hover (via mouseenter/mouseleave listeners) and animate based on the corresponding hover state
 * May accept a ref to forward to the HTML tag delegate
 * May accept an overriding currentAnimation
 * @typeParam A additional animation names
 * @typeParam T the HTML Tag delegate
 */
declare const HoverAnimated: <A extends string = never, T extends keyof JSX.IntrinsicElements = "div">(props: {
    /**
     * The optional currentAnimation override that may control this component
     * If present, will override the animation for the current hover state
     * If null or undefined, the component will animate based on the hover state
     * Analogous to currentAnimation in {@link components/ControlledAnimated.ControlledAnimatedProps}
     */
    currentAnimation?: A;
} & import("./common").NonHTMLAnimatedProps<HoverAnimations | A, T> & Omit<import("./common").TagHTMLAttributes<T>, "onAnimationEnd"> & React.RefAttributes<TagHTMLElement<T>>) => React.ReactElement<any, any>;
export default HoverAnimated;
