import { SetStateAction } from 'react';
/**
 * State that supports asynchronous state transitions
 * State transitions may be enqueued and then completed in FIFO order via transition or transitionAll
 */
export interface QueuedTransitionState<S> {
    /**
     * Current state value
     */
    readonly current: S;
    /**
     * enqueue a state transition - either a literal value or a function (prev) => next
     */
    readonly enqueue: (action: SetStateAction<S>) => void;
    /**
     * process one queued transition
     */
    readonly transition: () => void;
    /**
     * process all queued transitions
     */
    readonly transitionAll: () => void;
}
declare function useQueuedState<S = unknown>(): QueuedTransitionState<S | undefined>;
/**
 * State is always a defined S if an initial state is provided
 */
declare function useQueuedState<S>(initialState: S): QueuedTransitionState<S>;
export default useQueuedState;
