"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const useTransitioningState_1 = __importDefault(require("./useTransitioningState"));
/**
 * Hook to use a boolean toggle state that supports asynchronous transitions
 *
 * Toggle transitions may be queued via startToggling, and all queued toggles are completed by endTransition
 *
 * @param initialState
 * @param initialTransitioning if true, will toggle away from initialState when the togglingElementRef is first set
 *
 * @return [isToggled, startToggling, endToggling, currentTransition]: TransitioningToggleState
 */
function useTransitioningToggle(initialState = false, initialTransitioning = false) {
    const [isToggled, startTransition, endTransition, isTransitioning] = (0, useTransitioningState_1.default)(initialState, initialTransitioning ? nextTransition(initialState) : null);
    const transition = nextTransition(isToggled);
    const startToggling = (0, react_1.useCallback)((isAsync = true) => startTransition((prev) => !prev, isAsync ? transition : null), [transition]);
    const currentTransition = isTransitioning !== null ? transition : null;
    return [isToggled, startToggling, endTransition, currentTransition];
}
const nextTransition = (isToggled) => (isToggled ? 'togglingOff' : 'togglingOn');
exports.default = useTransitioningToggle;
